/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2018.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#pragma once

/**
 * @brief       The namespace opVTKMesh contains an implementation of a VTK mesher.
 */
namespace opVTKMesh
{

/**
 * @brief       The namespace opVTKMesh::action contains operator to create mesh with VTK .
 */
namespace action
{

} // namespace action

} // namespace opVTKMesh
